#
# spec file for package libxslt-python (Version 1.1.24)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           libxslt-python
BuildRequires:  libxml2-python libxslt-devel python-devel
Summary:        Python Bindings for libxslt
Version:        1.1.24
Release:        21
License:        X11/MIT
Group:          Development/Libraries/Python
Source:         libxslt-%{version}.tar.bz2
# Uncomment to save space:
#NoSource:      0
Patch0:         libxslt-%{version}-linkflags.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{py_requires}
Requires:       libxml2 >= 2.6.27
Url:            http://xmlsoft.org/XSLT/

%description
The libxslt-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libxslt library to apply XSLT transformations.

This library allows parsing stylesheets. It uses the libxml2-python to
load and save XML and HTML files. Direct access to XPath and the XSLT
transformation context are possible. Thus it is possible to extend the
XSLT language with XPath functions written in Python.



Authors:
--------
    Daniel Veillard <daniel@veillard.com>

%prep
%setup -q -n libxslt-%{version}
%patch0

%build
autoreconf --force --install
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
%configure
# use libxslt as built by libxslt source package
mkdir libxslt/.libs libexslt/.libs
cp -v %{_libdir}/libxslt.la libxslt
cp -v %{_libdir}/libexslt.la libexslt
make -C python

%install
export RPM_BUILD_ROOT
make -C python install \
	DESTDIR=$RPM_BUILD_ROOT \
	pythondir=%{py_sitedir} \
	PYTHON_SITE_PACKAGES=%{py_sitedir}
# Unwanted doc stuff
rm -fr $RPM_BUILD_ROOT%{_datadir}/doc
# #223696
rm -f $RPM_BUILD_ROOT%{py_sitedir}/*.{la,a}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%{py_sitedir}/*
# %{python_sitepath}/libxslt.py
# %{python_sitepath}/libxsltmod.so
%doc python/TODO
%doc python/libxslt-python-api.xml
%doc python/tests/*.py
%doc python/tests/*.xml
%doc python/tests/*.xsl

%changelog
* Fri Apr 11 2008 prusnak@suse.cz
- updated to 1.1.23
  * Documentation
  fix links for Cygwin DocBook setup (Philippe Bourcier)
      - xsltParseStylesheetDoc doc fix (Jason Viers)
      - fix manpage default maxdepth value
  * Bug fixes:
      - python segfault (Daniel Gryniewicz)
      - week-in-year bug fix (Maurice van der Pot)
      - fix python iterator problem (William Brack)
      - avoid garbage collection problems on str:tokenize and str:split
  and function results (William Brack and Peter Pawlowski)
      - superfluous re-generation of keys (William Brack)
      - remove superfluous code in xsltExtInitTest (Tony Graham)
      - func:result segfault fix (William Brack)
      - timezone offset problem (Peter Pawlowski),
  * Portability fixes:
      - old gcrypt support fix (Brent Cowgill)
      - Python portability patch (Stephane Bidoul)
      - VS 2008 fix (Rob Richard)
* Tue Jan 22 2008 prusnak@suse.cz
- build without strict aliasing (as main package does)
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 1.1.22:
  * Bug fixes: RVT cleanup problems, exclude-result-prefix bug,
  stylesheet compilation error handling, out of memory allocation
  errors, namespace problem on compound predicates, python
  space/tab inconsistencies, hook xsl:message to per
  transformation error callbacks, cached RVT problem, XPath
  context maintainance on choose, memory leaks in the math
  module, exclude-result-prefix induced namespace problem
  * Portability fixes: improve build with VS2005, fixing build on
  AIX, fix the security file checks on Windows.
  * Improvement: add an --encoding option to xsltproc.
  * Build: configure setup for TRIO_REPLACE_STDIO
  * Documentation: updated after change from CVs to SVN
* Mon Aug 20 2007 sbrabec@suse.cz
- Commented out NoSource to provide comfortable rebuild.
* Thu Jan 25 2007 prusnak@suse.cz
- update to 1.1.20
  * sync to libxslt-1.1.20
- drop obsolete patches:
  * libxslt-transform.patch (included in update)
* Thu Jan 11 2007 ke@suse.de
- Adjust python-linkflags.patch for 1.1.19 and do not apply obsolete
  warn patch.
* Tue Dec 12 2006 ke@suse.de
- 1.1.19.
* Tue Nov 28 2006 ke@suse.de
- Do not install static Python module; reported by Andreas Hanke
  [#223696].
* Fri Jun 16 2006 ke@suse.de
- 1.1.17.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Sep 30 2005 aj@suse.de
- Fix compiler warnings.
* Fri Sep 16 2005 ke@suse.de
- Update to version 1.1.15.
* Wed Jul 06 2005 meissner@suse.de
- removed -fno-strict-aliasing, not needed here.
* Mon Apr 04 2005 ke@suse.de
- Update to version 1.1.14.
* Wed Nov 24 2004 mcihar@suse.cz
- use rpm macros to build correcly with current python
* Tue Nov 02 2004 ke@suse.de
- Update to version 1.1.12.
* Tue Oct 12 2004 ke@suse.de
- Add libgcrypt* and libgpg-error* to neededforbuild.
* Fri Oct 08 2004 ke@suse.de
- Update to version 1.1.11.
* Mon Aug 23 2004 ke@suse.de
- Update to version 1.1.9.
* Thu Aug 19 2004 schwab@suse.de
- Fix a broken cast.
* Wed Jul 14 2004 ke@suse.de
- Update to version 1.1.8.
* Fri May 21 2004 ke@suse.de
- Update to version 1.1.7.
* Tue Apr 20 2004 ke@suse.de
- Update to version 1.1.6.
* Fri Dec 12 2003 ke@suse.de
- Update to version 1.1.1.
* Wed Nov 05 2003 ke@suse.de
- Update to version 1.1.0; for details cf. the libxslt changelog.
* Fri Aug 29 2003 mcihar@suse.cz
- require same python version as it was built with
* Fri Aug 15 2003 ke@suse.de
- Update to version 1.0.32; for details cf. the libxslt changelog.
* Wed Jul 09 2003 ke@suse.de
- Update to version 1.0.31; for details cf. the libxslt changelog.
* Tue Jun 17 2003 sbrabec@suse.cz
- Updated to version 1.0.30.
* Mon May 26 2003 ke@suse.de
- Remove unwanted files from $RPM_BUILD_ROOT.
* Wed Apr 02 2003 ke@suse.de
- Update to version 1.0.29; for details cf. the libxslt changelog.
* Wed Mar 26 2003 ke@suse.de
- Update to version 1.0.28; for details cf. the libxslt changelog.
* Tue Feb 11 2003 ke@suse.de
- Update to version 1.0.26; for details cf. the libxslt changelog.
* Thu Feb 06 2003 ke@suse.de
- Update to version 1.0.25; for details cf. the libxslt changelog.
* Wed Jan 15 2003 ke@suse.de
- Update to version 1.0.24.
* Tue Nov 26 2002 ro@suse.de
- split specfile to get rid of python dependencies in the main tree
